<?php
ini_set('display_errors','On');
session_start();

if($_GET['opt']=='salir'){
    session_destroy();
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
    exit;
}

/*
LOGIN ADMINISTRATIVO
*/

if(($_GET['opt']=='login') && ($_POST['txtUsuario']=='agrobonosadmin')){
    $usuario = strtoupper(trim($_POST['txtUsuario']));
    $clave = strtoupper(trim($_POST['txtClave']));
    $tipo = strtoupper(trim($_POST['tipo']));
    
    if($usuario!='' && $clave!=''){
        if(strlen($clave) < 1){
            $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
        }else if(strlen($clave) > 16){
            $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
        }else {
            
            require_once ($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUtils.php');
            $objSeg = new clsUtils();
            $r = $objSeg->ObtenerIP_Publica();
            $_SESSION['IP']=$r;
            $r = $objSeg->ObtenerIP();
            $_SESSION['IP'] = $_SESSION['IP'].' - '.$r;
            include_once($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUsuario.php');
            
            $objUsr = new clsUsuario();
        
            $exito = $objUsr->MET_existeusuarioAdmin($usuario, $clave, $_SESSION['IP'], $tipo);
            if($exito){
                $_SESSION['msj_sistema'] = '';            
                $_SESSION['num_identificacion']=$usuario;
                $_SESSION['tip_cambiar']=0;
                $_SESSION['razon_social']='Administrador Agrobonos';
                header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php');
                exit;
            }else{
                $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
                header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
                exit;
            }
        }
    }else{
        $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
        header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
        exit;
    }
    $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
    exit;
}

/*
LOGIN ADMINISTRATIVO
*/

if($_GET['opt']=='login'){
    $usuario = strtoupper(trim($_POST['txtUsuario']));
    $clave = strtoupper(trim($_POST['txtClave']));
    $tipo = strtoupper(trim($_POST['tipo']));
    if($usuario!='' && $clave!=''){
        if(strlen($clave) < 1){
            $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
        }else if(strlen($clave) > 16){
            $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
        }else {
            require_once ($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUtils.php');
            $objSeg = new clsUtils();
            $r = $objSeg->ObtenerIP_Publica();
            $_SESSION['IP']=$r;
            $r = $objSeg->ObtenerIP();
            $_SESSION['IP'] = $_SESSION['IP'].' - '.$r;
            include_once($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUsuario.php');
            
            $objUsr = new clsUsuario();
        
            $exito = $objUsr->MET_existeusuario($usuario, $clave, $_SESSION['IP'], $tipo);
            if($exito){
                $_SESSION['msj_sistema'] = '';            
                $_SESSION['num_identificacion']=$usuario;
                $_SESSION['tip_categoria']=$exito['tip_categoria'];
                $_SESSION['tip_cambiar']=0;
                $_SESSION['razon_social']=$exito['ape_cia'].' '.$exito['nom_cia'];
                $_SESSION['nom_lider']=$exito['nom_lider'];
                $_SESSION['nom_director']=$exito['nom_director'];
                $_SESSION['tipo_usuario']=$tipo;
                header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php');
                exit;
            }else{
                $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
                header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
                exit;
            }
        }
    }else{
        $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
        header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
        exit;
    }
    $_SESSION['msj_sistema'] = 'Usuario o clave incorrectos';
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/login.php');
    exit;
}

if($_GET['opt']=='perfil'){
    $nombre = strtoupper(trim($_POST['txtNombre']));
    $apellido = strtoupper(trim($_POST['txtApellido']));
    $identificacion = strtoupper(trim($_POST['txtIdentificacion']));
    $direccion = strtoupper(trim($_POST['txtDireccion']));
    $email = strtolower(trim($_POST['txtEmail']));
    $celular = strtoupper(trim($_POST['txtCelular']));
    $telefono = strtoupper(trim($_POST['txtTelefono']));
    if($nombre!='' && $apellido!='' && $identificacion!='' && $direccion!=''){
        require_once($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUsuario.php');
        $objUsr = new clsUsuario();
        if($identificacion!=$_SESSION['num_identificacion']){
            $existe = $objUsr->MET_consultarPerfil($identificacion);
            if(!$existe){
                $exito = $objUsr->MET_crearperfil($identificacion, $nombre, $apellido, $direccion, $email, $celular, $telefono);
                $exito2 = $objUsr->MET_crearusuario($identificacion);
                if($exito){
                    $_SESSION['msj_sistema'] = 'Se creo correctamente el perfil';            
                }else{
                    $_SESSION['msj_sistema'] = 'Existieron errores al crear el perfil';
                }
                header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=perfil&cod_cia='.$identificacion);
                exit;
            }else{
                $_SESSION['msj_sistema'] = 'Ya existe la empresaria';    
                header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=perfil&cod_cia=nuevo');
                exit;                    
            }                    
        }else{
            $exito = $objUsr->MET_modificarperfil($identificacion, $nombre, $apellido, $direccion, $email, $celular, $telefono);
            if($exito){
                $_SESSION['msj_sistema'] = 'Se actualizo correctamente el perfil';            
            }else{
                $_SESSION['msj_sistema'] = 'Existieron errores al actualizar el perfil';
            }
        }    
    }
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=perfil');
    exit;
}

if($_GET['opt']=='nuevoperfil'){
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=perfil&cod_cia=nuevo');
    exit;
}

if($_GET['opt']=='consultacliente'){
    $usuario = strtoupper(trim($_POST['txtIdentificacion']));
    $tipo = strtoupper(trim($_POST['tipo']));
    include_once($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUsuario.php');
    $objUsr = new clsUsuario();
    $exito = $objUsr->MET_ConsultarCliente2($usuario, $tipo);
    
    $_SESSION['msj_sistema'] = '';            
    $_SESSION['num_identificacion']=$usuario;
    $_SESSION['tip_categoria']=$exito['tip_categoria'];
    $_SESSION['tip_cambiar']=0;
    $_SESSION['razon_social']=$exito['ape_cia'].' '.$exito['nom_cia'];
    $_SESSION['nom_lider']=$exito['nom_lider'];
    $_SESSION['nom_director']=$exito['nom_director'];
    $_SESSION['tipo_usuario']=$tipo;
    
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=reportesadmin');
    exit;
}

if($_GET['opt']=='limpiarcliente'){
    $_SESSION['msj_sistema'] = '';            
    $_SESSION['num_identificacion']='AGROBONOSADMIN';
    $_SESSION['tip_cambiar']=0;
    $_SESSION['razon_social']='Administrador Agrobonos';
    $_SESSION['tip_categoria']='';
    $_SESSION['nom_lider']='';
    $_SESSION['nom_director']='';
    $_SESSION['tipo_usuario']='';
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=reportesadmin');
    exit;
}
 
if($_GET['opt']=='clave'){
    $actual = strtoupper(trim($_POST['txtActual']));
    $nueva1 = strtoupper(trim($_POST['txtNueva1']));
    $nueva2 = strtoupper(trim($_POST['txtNueva2']));
    if($actual!='' && $nueva1!='' && $nueva2!=''){
        if($actual == $nueva1){
            $_SESSION['msj_sistema'] = 'La clave nueva no puede ser igual a la anterior';
        }else if($nueva1 == $nueva2){
            require_once($_SERVER['DOCUMENT_ROOT'].'/shine/model/clsUsuario.php');
            $objUsr = new clsUsuario();
            $exito = $objUsr->MET_cambiarclave($actual, $nueva1);
            if($exito){
                $_SESSION['msj_sistema'] = 'La clave se actualizó correctamente';
            }else{
                $_SESSION['msj_sistema'] = 'No se pudo cambiar la clave';
            }
        }else{
            $_SESSION['msj_sistema'] = 'Las nuevas claves no coinciden';
        }
    }else{
        $_SESSION['msj_sistema'] = 'Campos incompletos';
    }
    header('Location: http://'.$_SERVER['HTTP_HOST'].'/shine/index.php?opt=clave');
    exit;
}

